@@ -20,7 +20,7 @@ __all__ = [
     "SymbolicExpression",
     "SymAddrAddr",
     "SymAddrConst",
-    "SymStackConst",
+    "Variant",
 ]
 
 from .auxdata import AuxData, AuxDataContainer
@@ -32,14 +32,9 @@ from .module import Module
 from .node import Node
 from .offset import Offset
 from .section import Section
-from .serialization import Serialization
+from .serialization import Serialization, Variant
 from .symbol import Symbol
-from .symbolicexpression import (
-    SymAddrAddr,
-    SymAddrConst,
-    SymbolicExpression,
-    SymStackConst,
-)
+from .symbolicexpression import SymAddrAddr, SymAddrConst, SymbolicExpression
 from .version import API_VERSION
 
 __version__ = API_VERSION
