@@ -4,12 +4,7 @@ from uuid import UUID
 from .block import ByteBlock, CodeBlock, DataBlock
 from .node import Node
 from .proto import ByteInterval_pb2, SymbolicExpression_pb2
-from .symbolicexpression import (
-    SymAddrAddr,
-    SymAddrConst,
-    SymbolicExpression,
-    SymStackConst,
-)
+from .symbolicexpression import SymAddrAddr, SymAddrConst, SymbolicExpression
 from .util import DictLike, SetWrapper, get_desired_range, nodes_at, nodes_on
 
 SymbolicExpressionElement = typing.Tuple[
@@ -77,7 +72,8 @@ class ByteInterval(Node):
         contents=b"",  # type: typing.ByteString
         blocks=(),  # type: typing.Iterable[ByteBlock]
         symbolic_expressions={},  # type: DictLike[int, SymbolicExpression]
-        uuid=None  # type: typing.Optional[UUID]
+        uuid=None,  # type: typing.Optional[UUID]
+        section=None  # type: typing.Optional["Section"]
     ):
         """
         :param address: The fixed address of this interval, if present.
@@ -91,6 +87,7 @@ class ByteInterval(Node):
         :param uuid: The UUID of this ``ByteInterval``,
             or None if a new UUID needs generated via :func:`uuid.uuid4`.
             Defaults to None.
+        :param section: The :class:`Section` this interval belongs to.
         """
 
         if size is None:
@@ -116,6 +113,9 @@ class ByteInterval(Node):
             None
         )  # type: typing.Optional[ByteInterval_pb2.ByteInterval]
 
+        # Use the property setter to ensure correct invariants.
+        self.section = section
+
     @property
     def initialized_size(self):
         # type: () -> int
@@ -188,11 +188,7 @@ class ByteInterval(Node):
         """
 
         def decode_symbolic_expression(proto_expr):
-            if proto_expr.HasField("stack_const"):
-                return SymStackConst._from_protobuf(
-                    proto_expr.stack_const, ir.get_by_uuid
-                )
-            elif proto_expr.HasField("addr_const"):
+            if proto_expr.HasField("addr_const"):
                 return SymAddrConst._from_protobuf(
                     proto_expr.addr_const, ir.get_by_uuid
                 )
@@ -250,9 +246,7 @@ class ByteInterval(Node):
 
         for k, v in self.symbolic_expressions.items():
             sym_exp = SymbolicExpression_pb2.SymbolicExpression()
-            if isinstance(v, SymStackConst):
-                sym_exp.stack_const.CopyFrom(v._to_protobuf())
-            elif isinstance(v, SymAddrConst):
+            if isinstance(v, SymAddrConst):
                 sym_exp.addr_const.CopyFrom(v._to_protobuf())
             elif isinstance(v, SymAddrAddr):
                 sym_exp.addr_addr.CopyFrom(v._to_protobuf())
